@@ -279,6 +279,7 @@ class Campaign:
         send_if_duplicate: bool,
         has_anniversary_drip: bool = False,
         has_birthday_drip: bool = False,
+        total_cost: int = 0,
     ) -> None:
         self._id = id
         self._name = name
@@ -286,6 +287,7 @@ class Campaign:
         self._send_if_duplicate = send_if_duplicate
         self._has_anniversary_drip = has_anniversary_drip
         self._has_birthday_drip = has_birthday_drip
+        self._total_cost = total_cost
 
     __repr__ = helpers.repr
 
@@ -319,6 +321,11 @@ class Campaign:
         """True if one of more drips in this campaign are birthday drips. False otherwise."""
         return self._has_birthday_drip
 
+    @property
+    def total_cost(self) -> int:
+        """Drip campaign's total cost in `cents`."""
+        return self._total_cost
+
     @classmethod
     def _from_json(cls, json: dict):
         return cls(
@@ -328,6 +335,7 @@ class Campaign:
             send_if_duplicate=json['send_even_if_duplicate'],
             has_anniversary_drip=json['has_anniversary_drip'],
             has_birthday_drip=json['has_birthday_drip'],
+            total_cost=json['campaign_cost'],
         )
 
 class CardStatus(Enum):
@@ -875,11 +883,13 @@ class CampaignMultiResponse:
         mailing_id: int,
         contacts_scheduled_count: int,
         duplicate_contacts_count: int,
+        contacts_scheduled_third_party_contact_ids: List[str],
         message: str,
     ) -> None:
         self._mailing_id = mailing_id
         self._contacts_scheduled_count = contacts_scheduled_count
         self._duplicate_contacts_count = duplicate_contacts_count
+        self._contacts_scheduled_third_party_contact_ids = contacts_scheduled_third_party_contact_ids
         self._message = message
 
     __repr__ = helpers.repr
@@ -904,6 +914,11 @@ class CampaignMultiResponse:
         """Number of contacts that were duplicates and not scheduled."""
         return self._duplicate_contacts_count
 
+    @property
+    def contacts_scheduled_third_party_contact_ids(self) -> List[str]:
+        """List of third party contact ids that were scheduled for the drip campaign."""
+        return self._contacts_scheduled_third_party_contact_ids
+
     @property
     def message(self) -> str:
         """Represents AMcards' response message for sending a drip campaign to multiple contacts."""
@@ -915,6 +930,7 @@ class CampaignMultiResponse:
             mailing_id=json['mailing_id'],
             contacts_scheduled_count=json['contacts_scheduled_count'],
             duplicate_contacts_count=json['duplicate_contacts_count'],
+            contacts_scheduled_third_party_contact_ids=json['contacts_scheduled_third_party_contact_ids'],
             message=json['message'],
         )
 
